@@ -5,7 +5,7 @@
 #'   based.
 #'   
 #'   If \code{color = "z-score"}, surface coloring will be based on median of
-#'   standartized off-axis Z-scores. Median function can be replaced by other
+#'   standardized off-axis Z-scores. Median function can be replaced by other
 #'   function using an optional \code{colorfun} argument which will be passed to
 #'   \code{plotResponseSurface}. Color breaks are determined here by standard
 #'   deviation of off-axis Z-scores. For \code{color = "maxR"}, coloring will be
@@ -15,25 +15,44 @@
 #'   If \code{color = "effect-size"}, coloring will be
 #'   based on effect size for the respective dose combination.
 #'
+#' @param greyScale If \code{greyScale = TRUE}, then plot is in grey scale,
+#'   otherwise in colour.
 #' @param ... Further parameters passed to \code{\link{plotResponseSurface}}.
 #'   \code{colorBy} argument in this method is computed automatically and thus
 #'   cannot be passed to \code{\link{plotResponseSurface}}.
 #' @export
-plot.ResponseSurface <- function(x, color = c("z-score", "maxR", "occupancy", "effect-size"), ...) {
-
+plot.ResponseSurface <- function(x, color = c("z-score", "maxR", "occupancy", "effect-size"), greyScale = FALSE, ...) {
+  
   color <- match.arg(color)
   inputs <- as.list(substitute(list(...)))[-1L]
-
-  ## Blue is synergy, red is antagonism
+  reverse <- FALSE
+  
+  
+  # Blue is synergy, red is antagonism
   if(!exists("colorPalette", inputs)) {
-    inputs$colorPalette <- c("red", rep("grey70", 2), "blue")
-    if (x$fitResult$coef["b"] >= x$fitResult$coef["m1"] && 
-        x$fitResult$coef["b"] >= x$fitResult$coef["m2"]) {
+
+    if(greyScale){    #      inputs$colorPoints = c("black", "#AAAAAA", "#AAAAAA", "white")
+      if(color == "effect-size"){
+        inputs$colorPalette <- c("#636363", "grey70", "#FEFCFF")
+      } else {
+        inputs$colorPalette <- c("#636363", rep("grey70", 2), "#FEFCFF")
+      }
+    } else  {
+      if(color == "effect-size"){
+        inputs$colorPalette <- c("red", "grey70", "blue")
+      } else {
+        inputs$colorPalette <- c("red", rep("grey70", 2), "blue")
+      }
+    }
+    
+    if (x$fitResult$coef["b"] >= x$fitResult$coef["m1"] &&
+        x$fitResult$coef["b"] >= x$fitResult$coef["m2"]) {  # b >= m1, m2 decreasing curves so labels are changed; if b < m1, m2 colours preserved
+      reverse <- TRUE
       inputs$colorPalette <- rev(inputs$colorPalette)
     }
     # TODO: what to do in the 'undefined' case - agonist+antagonist or both flat?
-  }
-
+  } 
+  
   #TODO include the name of the `color` to be used in the legend of `plotResponseSurface()`
   
   if (color == "z-score") {
@@ -56,38 +75,46 @@ plot.ResponseSurface <- function(x, color = c("z-score", "maxR", "occupancy", "e
     if(is.null(x$confInt))
       stop("No confidence intervals were calculated")
     if (!exists("main", inputs)) inputs$main <- "Effect size"
-    synOut <- x$maxR$Ymean
-    names(synOut)[names(synOut) == "call"] <- "synCall"
+    # synOut <- x$maxR$Ymean
+    # names(synOut)[names(synOut) == "call"] <- "synCall"
     effectOut <- x$confInt$offAxis
     names(effectOut)[names(effectOut) == "call"] <- "effectCall"
     effectOut$d1 <- as.numeric(gsub("(.+)_.+", "\\1", rownames(effectOut)))
     effectOut$d2 <- as.numeric(gsub(".+_(.+)", "\\1", rownames(effectOut)))
-    x_new <- merge(synOut, effectOut, by = c("d1","d2"))
+    x_new <- effectOut
+    # x_new <- merge(synOut, effectOut, by = c("d1","d2"))
     inputs$colorBy <- x_new[, c("d1", "d2", "effectCall")]
     if (!exists("breaks", inputs)) inputs$breaks <- seq_len(4)
   }
-
+  
   inputs$data <- x$data
   inputs$fitResult <- x$fitResult
   inputs$transforms <- x$transforms
   inputs$null_model <- x$null_model
-
+  inputs$reverse <- reverse
+  
   do.call(plotResponseSurface, inputs)
-
+  
 }
 
 #' Method for plotting of contours based on maxR statistics
 #'
 #' @param x Output of \code{\link{fitSurface}}
 #' @param colorBy String indicating the characteristic to use for coloring ("maxR" or "effect-size"). By default, "maxR".
-#' @param ... Further parameters passed to \code{\link{plot.maxR}}
+#' @param reverse.x Reverse x axis?
+#' @param reverse.y Reverse y axis?
+#' @param swapAxes Swap x and y axes?
+#' @param greyScale If \code{greyScale = TRUE}, then plot is in grey scale,
+#'   otherwise in colour.
+#' @param ... Further parameters passed to \code{\link{plot.maxR}} or \code{\link{plot.effect-size}}
 #' @export
-contour.ResponseSurface <- function(x, colorBy = "maxR", ...) {
+contour.ResponseSurface <- function(x, colorBy = "maxR", reverse.x = FALSE, reverse.y = FALSE, swapAxes = FALSE, greyScale = FALSE, ...) {
   
   if (!exists("maxR", x))
     stop("maxR statistics were not found.")
-
+  
   cpdNames <- if (!is.null(x$names)) x$names else c("Compound 1", "Compound 2")
+  
   args <- list(...)
   if (!exists("xlab", args))
     args$xlab <- paste0("Dose (", cpdNames[[1]], ")")
@@ -96,7 +123,14 @@ contour.ResponseSurface <- function(x, colorBy = "maxR", ...) {
   
   ## Blue is synergy, red is antagonism
   if (!exists("colorPalette", args)) {
-    args$colorPalette <- c("red", "white", "blue")
+    
+    if(greyScale){
+      args$colorPalette <- c( "#636363", "grey70", "white")
+      #args$colorPalette <- c("#636363", "white", "#BDBDBD")
+    } else {
+      args$colorPalette <- c("red", "white", "blue")
+    }
+
     names(args$colorPalette) <- c("Ant", "None", "Syn")
     if (x$fitResult$coef["b"] >= x$fitResult$coef["m1"] && 
         x$fitResult$coef["b"] >= x$fitResult$coef["m2"]) {
@@ -110,6 +144,11 @@ contour.ResponseSurface <- function(x, colorBy = "maxR", ...) {
   } else if (colorBy == "effect-size") {
     args$x <- x
   }
+  
+  args$reverse.x <- reverse.x
+  args$reverse.y <- reverse.y
+  args$swapAxes <- swapAxes
+  
   class(args$x) <- c(colorBy, setdiff(class(args$x), c("maxR", "effect-size")))
   do.call(plot, args)
   
@@ -121,20 +160,20 @@ contour.ResponseSurface <- function(x, colorBy = "maxR", ...) {
 #' @param ... Further parameters
 #' @export
 summary.ResponseSurface <- function(object, ...) {
-
+  
   ans <- list()
   ans$marginalFit <- summary(object$fitResult)
   ans$null_model <- object$null_model
   ans$shared_asymptote <- object$fitResult$shared_asymptote
-
+  
   if (!is.null(object$meanR)) ans$meanR <- summary(object$meanR)
   if (!is.null(object$maxR)) ans$maxR <- summary(object$maxR)
-
+  
   ans$occup <- if (!is.null(object$occupancy)) mean(object$occupancy$occupancy) else NULL
   ans$method <- object$method
   object$confInt$cutoff = object$cutoff
   ans$CI = summary(object$confInt)
-
+  
   class(ans) <- "summary.ResponseSurface"
   ans
 }
@@ -145,7 +184,7 @@ summary.ResponseSurface <- function(object, ...) {
 #' @param ... Further parameters
 #' @export
 print.summary.ResponseSurface <- function(x, ...) {
-
+  
   cat("Null model: ")
   if (x$null_model == "loewe" & x$shared_asymptote == TRUE)
     cat("Standard Loewe Additivity")
@@ -165,7 +204,7 @@ print.summary.ResponseSurface <- function(x, ...) {
     cat("Alternative generalization of Loewe Additivity")
   else
     cat(x$null_model)
-
+  
   cat("\n")
   cat("Variance assumption used:", dQuote(x$method))
   if (!is.null(x$occup)) {
@@ -175,20 +214,20 @@ print.summary.ResponseSurface <- function(x, ...) {
   cat("\n\n")
   print(x$marginalFit)
   cat("\n")
-
+  
   if (!is.null(x$meanR)) print(x$meanR)
   if (!is.null(x$maxR)) print(x$maxR)
-
+  
   if (is.null(x$meanR) & is.null(x$maxR)) {
     cat("\n\n")
     cat("No test statistics were computed.")
   }
-
+  
   if(!is.null(x$CI)) {
     cat("\nCONFIDENCE INTERVALS\n")
     print(x$CI)
   }
-
+  
   cat("\n")
 }
 
@@ -199,14 +238,14 @@ print.summary.ResponseSurface <- function(x, ...) {
 #' @param ... Further parameters
 #' @export
 fitted.ResponseSurface <- function(object, ...) {
-
+  
   doseInput <- object$data[, c("d1", "d2")]
   parmInput <- coef(object$fitResult)
-
+  
   switch(object$null_model,
          "loewe" = generalizedLoewe(doseInput, parmInput)$response,
          "hsa" = hsa(doseInput, parmInput),
          "bliss" = Blissindependence(doseInput, parmInput),
          "loewe2" = harbronLoewe(doseInput, parmInput))
-
-}
+  
+}
\ No newline at end of file
